==> percona-xtradb-cluster_8.0.34-26.orig.tar.gz: Percona-XtraDB-Cluster-8.0.34-26/unittest/gunit/sql_class_header-t.cc <==
/* Copyright (c) 2017, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

/*
  This test verifies that sql_class.h compiles by itself, and that it doesn't
  pull in a given set of headers that are known to increase compile time
  significantly.
*/

#include "sql/sql_class.h"

#ifdef SQL_LEX_INCLUDED
#error "sql_class.h includes sql_lex.h directly or indirectly; it should not."
#endif

#ifdef ITEM_INCLUDED
#error "sql_class.h includes item.h directly or indirectly; it should not."
#endif

#ifdef FIELD_INCLUDED
#error "sql_class.h includes field.h directly or indirectly; it should not."
#endif

#ifdef HANDLER_INCLUDED
#ifdef WITH_WSREP
/*
 * PS includes handler.h in mysqld.h. This is because definition of TABLE_STATS
 * struct is needed for
 * using table_stats_t = collation_unordered_map<std::string, TABLE_STATS>;
 *
 * PXC wsrep_mysqld.h includes mysqld.h and sql_class.h includes wsrep_mysqld.h
 * It is possible to decouple headers, but it needs changes in PS, which is
 * not needed there, so just to avoid these changes turn it into message now.
 */
#pragma message( \
    "sql_class.h includes handler.h directly or indirectly; it should not.")
#else
#error "sql_class.h includes handler.h directly or indirectly; it should not."
#endif
#endif

#ifdef _SQL_PROFILE_H
#error \
    "sql_class.h includes sql_profile.h directly or indirectly; it should not."
#endif

==> percona-xtradb-cluster_8.4.4-4.orig.tar.gz: Percona-XtraDB-Cluster-8.4.4-4/unittest/gunit/sql_class_header-t.cc <==
/* Copyright (c) 2017, 2024, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

/*
  This test verifies that sql_class.h compiles by itself, and that it doesn't
  pull in a given set of headers that are known to increase compile time
  significantly.
*/

#include "sql/sql_class.h"

#ifdef SQL_LEX_INCLUDED
#error "sql_class.h includes sql_lex.h directly or indirectly; it should not."
#endif

#ifdef ITEM_INCLUDED
#error "sql_class.h includes item.h directly or indirectly; it should not."
#endif

#ifdef FIELD_INCLUDED
#error "sql_class.h includes field.h directly or indirectly; it should not."
#endif

#ifdef HANDLER_INCLUDED
#ifdef WITH_WSREP
/*
 * PS includes handler.h in mysqld.h. This is because definition of TABLE_STATS
 * struct is needed for
 * using table_stats_t = collation_unordered_map<std::string, TABLE_STATS>;
 *
 * PXC wsrep_mysqld.h includes mysqld.h and sql_class.h includes wsrep_mysqld.h
 * It is possible to decouple headers, but it needs changes in PS, which is
 * not needed there, so just to avoid these changes turn it into message now.
 */
#pragma message( \
    "sql_class.h includes handler.h directly or indirectly; it should not.")
#else
#error "sql_class.h includes handler.h directly or indirectly; it should not."
#endif
#endif

#ifdef _SQL_PROFILE_H
#error \
    "sql_class.h includes sql_profile.h directly or indirectly; it should not."
#endif
